import vuetify, { transformAssetUrls } from 'vite-plugin-vuetify'
import { join } from 'node:path'

export default defineNuxtConfig({
  ssr: false,

  router: {
    options: {
      hashMode: true
    }
  },

  devtools: { enabled: true },
  css: ['vuetify/lib/styles/main.sass', '@mdi/font/css/materialdesignicons.min.css'],
  build: { transpile: ["vuetify"] },

  modules: [
    '@pinia/nuxt',
    '@vueuse/nuxt',
    async (options, nuxt) => {
      nuxt.hooks.hook("vite:extendConfig", (config) =>
        // @ts-ignore
        config.plugins.push(vuetify())
      );
    },
  ],

  runtimeConfig: {
    public: {
      coreApi: '',
    }
  },

  nitro: {
    output: {
      publicDir: join(__dirname, 'dist')
    }
  },

  vite: {
    vue: {
      template: {
        transformAssetUrls,
      },
    },
  },

  app: {
    baseURL: process.env.NODE_ENV === 'production' ? '.' : '/',
    head: {
      title: 'Policy Reporter UI',
      htmlAttrs: {
        lang: 'de'
      },
      meta: [
        { charset: 'utf-8' },
        { name: 'viewport', content: 'width=device-width, initial-scale=1' },
        { hid: 'description', name: 'description', content: '' },
        { name: 'format-detection', content: 'telephone=no' }
      ],
      link: [
        { rel: 'icon', type: 'image/x-icon', href: './favicon.ico' }
      ]
    }
  },

  compatibilityDate: '2024-07-28',
})